==> axis2-1.8.0-src.zip: axis2-1.8.0/modules/transport/jms/src/test/java/org/apache/axis2/transport/jms/JMSTextMessageFactory.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *   * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.apache.axis2.transport.jms;

import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.Session;
import javax.jms.TextMessage;

import org.apache.axis2.transport.testkit.name.Name;

@Name("text")
public class JMSTextMessageFactory implements JMSMessageFactory<String> {
    public static final JMSTextMessageFactory INSTANCE = new JMSTextMessageFactory();
    
    private JMSTextMessageFactory() {}

    public Message createMessage(Session session, String data) throws JMSException {
        TextMessage message = session.createTextMessage();
        message.setText(data);
        return message;
    }

    public String parseMessage(Message message) throws JMSException {
        return ((TextMessage)message).getText();
    }
}

==> axis2-2.0.0-src.zip: axis2-2.0.0/modules/transport/jms/src/test/java/org/apache/axis2/transport/jms/JMSTextMessageFactory.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *   * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.apache.axis2.transport.jms;

import jakarta.jms.JMSException;
import jakarta.jms.Message;
import jakarta.jms.Session;
import jakarta.jms.TextMessage;

import org.apache.axis2.transport.testkit.name.Name;

@Name("text")
public class JMSTextMessageFactory implements JMSMessageFactory<String> {
    public static final JMSTextMessageFactory INSTANCE = new JMSTextMessageFactory();
    
    private JMSTextMessageFactory() {}

    public Message createMessage(Session session, String data) throws JMSException {
        TextMessage message = session.createTextMessage();
        message.setText(data);
        return message;
    }

    public String parseMessage(Message message) throws JMSException {
        return ((TextMessage)message).getText();
    }
}
